import { IFrameCloseEvent, IFrameNotShownEvent } from './common';
import { ComponentDefinition } from './component-definition';
declare const Dropdown: "Dropdown";
declare const FacesRatingBar: "FacesRatingBar";
declare const TextInput: "TextInput";
declare const SegmentedToggle: "SegmentedToggle";
/**
 * @deprecated use ComponentDefinition
 */
export type ComponentType = typeof Dropdown | typeof FacesRatingBar | typeof TextInput | typeof SegmentedToggle;
export interface IBaseComponentStructure<TType extends ComponentType> {
    questionId: string;
    type: TType;
    label: string;
    placeholder?: string;
}
export interface ITextInputComponentStructure extends IBaseComponentStructure<typeof TextInput> {
}
export interface IDropdownComponentStructure extends IBaseComponentStructure<typeof Dropdown> {
    options: {
        id: string;
        displayName: string;
    }[];
}
export interface ISegmentedToggleComponentStructure extends IBaseComponentStructure<typeof SegmentedToggle> {
    buttons: {
        id: 'negative' | 'positive';
        displayName: string;
    }[];
}
export interface IFacesRatingBarComponentStructure extends IBaseComponentStructure<typeof FacesRatingBar> {
    tooltips?: [string, string, string, string, string];
}
export type IStructure<TType extends ComponentType> = {
    TextInput: ITextInputComponentStructure;
    Dropdown: IDropdownComponentStructure;
    SegmentedToggle: ISegmentedToggleComponentStructure;
    FacesRatingBar: IFacesRatingBarComponentStructure;
}[TType];
type Prettify<T> = {
    [K in keyof T]: T[K];
} & {};
type JSONPrimitive = string | number | boolean | null;
type JSONValue = JSONPrimitive | JSONObject | JSONArray;
type JSONArray = JSONValue[];
interface JSONObject {
    [prop: string]: JSONValue;
}
/**
 * @deprecated use ComponentDefinition
 */
export type Component = ITextInputComponentStructure | IDropdownComponentStructure | ISegmentedToggleComponentStructure | IFacesRatingBarComponentStructure;
export interface IFeedbackFormStructure {
    id: string;
    title: string;
    components: ComponentDefinition[];
}
export type IframePosition = 'center' | 'bottom-right';
export interface IFeedbackFormMetadata {
    uuid: string;
    language?: string;
    debug?: boolean;
    formVariantId?: string;
    origin?: string;
    appDefId?: string;
    editorType?: string;
    esi?: string;
    msid?: string;
    customFields?: JSONObject;
    position?: IframePosition;
}
interface FeedbackLoopOptionsBase extends Omit<IFeedbackFormStructure, 'id' | 'title' | 'components'>, IFeedbackFormMetadata {
    formSetId: string;
    title?: string;
    components?: ComponentDefinition[];
}
/**
 * All available options for integrations
 */
export type FeedbackLoopOptions = Prettify<FeedbackLoopOptionsBase>;
/**
 * Helper type for defining options for Public facing APIs
 */
export type RequestFeedbackLoopOptions = Prettify<Pick<FeedbackLoopOptions, 'formSetId' | 'formVariantId' | 'origin' | 'title' | 'components' | 'debug' | 'customFields'>>;
/**
 * Helper type for public facing `requestFeedbackLoop` integrations
 */
export type RequestFeedbackLoop<TOptions extends {} = RequestFeedbackLoopOptions> = (options: TOptions) => OpenFeedbackFormReturn;
/**
 * Public facing interface
 */
export type OpenFeedbackFormReturn = Promise<IFrameCloseEvent | IFrameNotShownEvent>;
export {};
//# sourceMappingURL=types.d.ts.map